/*
 * Copyright 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 * Danbooru Client is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Danbooru Client is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Danbooru Client. If not, see <http://www.gnu.org/licenses/>.
 */

#include "test_service.h"

#include <QLabel>
#include <KImageCache>

namespace Danbooru {

DanbooruServiceTest::DanbooruServiceTest(QUrl boardUrl, Danbooru::ApiType type):
    m_service(0),
    m_label(new QLabel())
{
    auto cache = new KImageCache("test-data", 48000000);
    cache->clear();
    cache->setPixmapCaching(true);
    
    switch(type) {
        case Danbooru::MoeBooru:
            m_service = new MoebooruService(boardUrl);
            break;
        case Danbooru::Danbooru:
            m_service = new DanbooruService(boardUrl);
            break;
    
    };
    
    qDebug() << m_service->apiType() << "type";
    m_service->setParent(this);
    m_service->setMaximumAllowedRating(Danbooru::Questionable);
    m_service->setMaxPosts(2);
    m_service->setImageCache(cache);
    connect(m_service, &DanbooruServiceBase::postDownloaded, this, &DanbooruServiceTest::showPostData);
    connect(m_service, &DanbooruServiceBase::poolDownloaded, this, &DanbooruServiceTest::showPoolData);
}

DanbooruServiceTest::~DanbooruServiceTest() {
    delete m_service;
    delete m_label;
}

void DanbooruServiceTest::testPostService() {
    m_service->getPostList();
}

void DanbooruServiceTest::testPoolService() {
    m_service->getPoolList(1 /*limit */);
}

void DanbooruServiceTest::testPoolRetrieval(int postid) {
    qDebug() << "getting ID" << postid;
    m_service->getPool(postid);
}

void DanbooruServiceTest::showPostData(DanbooruPost* post) {
    qDebug() << post->toString();
    m_label->setPixmap(post->pixmap());
    m_label->show();
}

void DanbooruServiceTest::showPoolData(DanbooruPool* pool) {
    qDebug() << "----";
    qDebug() << "Pool ID" << pool->id();
    qDebug() << "Pool name" << pool->name();
    qDebug() <<  "Pool description" << pool->description();
    qDebug() << "Pool post count" << pool->postCount();

}

DanbooruServiceBase* DanbooruServiceTest::service() const {
    return m_service;
}

} // namespace Danbooru
